@@ -154,12 +154,14 @@ launch_url (Launcher *launcher)
 {
 	GnomeDesktopItem *item;
 	const char *url;
+	char *free_url;
 	GError *error = NULL;
 	GdkScreen *screen;
 
 	g_return_if_fail (launcher != NULL);
 	g_return_if_fail (launcher->ditem != NULL);
 
+	/* FIXME panel_ditem_launch() should be enough for this! */
 	item = launcher->ditem;
 	url = gnome_desktop_item_get_string (item,
 					     GNOME_DESKTOP_ITEM_URL);
@@ -177,7 +179,9 @@ launch_url (Launcher *launcher)
 		return;
 	}
 
-	gnome_url_show_on_screen (url, screen, &error);
+	free_url = gnome_vfs_make_uri_canonical (url);
+	gnome_url_show_on_screen (free_url, screen, &error);
+
 	if (error) {
 		GtkWidget *error_dialog;
 	
@@ -186,11 +190,13 @@ launch_url (Launcher *launcher)
 						   TRUE,
 						   _("Could not show '%s'"),
 						   "%s",
-						   url,
+						   free_url,
 						   error->message);
 		launcher_register_error_dialog (launcher, error_dialog);
 		g_clear_error (&error);
 	}
+
+	g_free (free_url);
 }
 
 void
